@@ -37,11 +37,12 @@ def _safe_post_request(url: str, body: dict):
         return None
 
 
-def node_type_to_url(node_type: SchemaType): return f"{node_type.value.lower()}s"
+def node_type_to_url(node_type: SchemaType):
+    return f"{node_type if isinstance(node_type, str) else node_type.value}s".lower()
 
 
 def node_to_path(node_type: SchemaType, node_id: str, data_state=None):
-    jsonld_path = os.path.join(node_type.value, f"{node_id}.jsonld")
+    jsonld_path = os.path.join(node_type if isinstance(node_type, str) else node_type.value, f"{node_id}.jsonld")
     return jsonld_path if data_state is None or len(data_state) == 0 else os.path.join(data_state, jsonld_path)
 
 
